<?php
/**
 * Taxes class
 *
 * @link       https://www.fredericgilles.net/fg-prestashop-to-woocommerce/
 * @since      3.51.0
 *
 * @package    FG_Prestashop_to_WooCommerce_Premium
 * @subpackage FG_Prestashop_to_WooCommerce_Premium/admin
 */

if ( !class_exists('FG_Prestashop_to_WooCommerce_Taxes', false) ) {

	/**
	 * Taxes class
	 *
	 * @package    FG_Prestashop_to_WooCommerce_Premium
	 * @subpackage FG_Prestashop_to_WooCommerce_Premium/admin
	 * @author     Frédéric GILLES
	 */
	class FG_Prestashop_to_WooCommerce_Taxes {

		private $plugin;
		private $imported_tax_classes = array();
		
		/**
		 * Initialize the class and set its properties.
		 *
		 * @param    object    $plugin       Admin plugin
		 */
		public function __construct( $plugin ) {
			$this->plugin = $plugin;
		}

		/**
		 * Reset the Prestashop last imported tax rules group ID
		 *
		 */
		public function reset_taxes() {
			update_option('fgp2wc_last_tax_rules_group_id', 0);
		}
		
		/**
		 * Import the PrestaShop tax rules groups
		 *
		 */
		public function import_tax_rules_groups() {
			
			if ( $this->plugin->import_stopped() ) {
				return;
			}
			$this->plugin->log(__('Importing taxes...', $this->plugin->get_plugin_name()));
			$wc_tax_classes_str = get_option('woocommerce_tax_classes');
			$wc_tax_classes = explode("\n", $wc_tax_classes_str);
			
			$tax_rules_groups = $this->get_tax_rules_groups();
			$imported_tax_rules_groups_count = 0;
			
			foreach ( $tax_rules_groups as $tax_rules_group ) {
				if ( !in_array($tax_rules_group['name'], $wc_tax_classes) ) {
					$wc_tax_classes[] = $tax_rules_group['name'];
					$imported_tax_rules_groups_count++;
				}
				$this->imported_tax_classes[$tax_rules_group['id_tax_rules_group']] = $tax_rules_group['name'];
				
				// Increment the last imported cart rule ID
				update_option('fgp2wc_last_cart_rule_id', $tax_rules_group['id_tax_rules_group']);
			}
			// Store the tax classes
			update_option('woocommerce_tax_classes', implode("\n", $wc_tax_classes));
			
			$this->plugin->display_admin_notice(sprintf(_n('%d tax rules group imported', '%d tax rules groups imported', $imported_tax_rules_groups_count, $this->plugin->get_plugin_name()), $imported_tax_rules_groups_count));
		}

		/**
		 * Get the PrestaShop tax rules groups
		 *
		 * @return array of tax rules groups
		 */
		private function get_tax_rules_groups() {
			$tax_rules_groups = array();

			$last_tax_rules_group_id = (int)get_option('fgp2wc_last_tax_rules_group_id'); // to restore the import where it left

			$prefix = $this->plugin->plugin_options['prefix'];
			$sql = "
				SELECT t.id_tax_rules_group, t.name
				FROM ${prefix}tax_rules_group t
				WHERE t.active = 1
				AND t.deleted = 0
				AND t.id_tax_rules_group > '$last_tax_rules_group_id'
				ORDER BY t.id_tax_rules_group
			";
			$tax_rules_groups = $this->plugin->prestashop_query($sql);

			return $tax_rules_groups;
		}
		
		/**
		 * Update the tax class for the product
		 * 
		 * @param int $new_post_id WP Post ID
		 * @param array $product Product data
		 */
		public function update_product_tax_class($new_post_id, $product) {
			if ( isset($product['id_tax_rules_group']) && array_key_exists($product['id_tax_rules_group'], $this->imported_tax_classes) ) {
				$meta_value = sanitize_title($this->imported_tax_classes[$product['id_tax_rules_group']]);
				add_post_meta($new_post_id, '_tax_status', 'taxable', true);
				add_post_meta($new_post_id, '_tax_class', $meta_value, true);
			}
		}
		
	}
}
